# tmdr-distribution package

This package provides classes of common probability distributions, i.e. teh Gaussian and the Binomial distributions

# Files

Inside the distributions folder, Binomialdistribution.py contains the code for the Binomial distribution, Gaussiandistribution.py contains the code for the gaussian distribution, and Generaldistribution.py contains the code of parent distribution of both the Gaussian and the Binomial

# Installation

To install, type <pip install tmdr-distribution> on your terminal